@@ -1,5 +1,5 @@
-"""Top-level package for cem."""
-
 __author__ = """Lewis Bails"""
 __email__ = 'lewis.bails@gmail.com'
-__version__ = '0.1.0'
+__version__ = '0.1.5'
+from .cem import CEM
+__all__ = ["CEM"]
